@@ -171,10 +171,13 @@ class Platform(object):
         """
         Create a platform object from a namespace build string
         """
+        match = []
         for system, platform in cls.SUPPORTED.items():
             for machine, platform_guess in platform.items():
-                if platform_guess in build_string:
-                    return cls(system, machine)
+                if platform_guess in build_string and (not match or len(match[2]) < len(platform_guess)):
+                    match = [system, machine, platform_guess]
+        if match:
+            return cls(match[0], match[1])
         raise FetcherException('Could not extract platform from %s' % (build_string,))
 
     def auto_name_prefix(self):
@@ -197,8 +200,7 @@ class Platform(object):
 
 class BuildTask(object):
     """Class for storing TaskCluster build information"""
-    TASKCLUSTER_APIS = ('https://firefox-ci-tc.services.mozilla.com/api/%s/v1',
-                        'https://%s.taskcluster.net/v1',)
+    TASKCLUSTER_API = 'https://firefox-ci-tc.services.mozilla.com/api/%s/v1'
     RE_DATE = re.compile(r'^\d{4}-\d{2}-\d{2}$')
     RE_REV = re.compile(r'^([0-9A-F]{12}|[0-9A-F]{40})$', re.IGNORECASE)
 
@@ -250,7 +252,7 @@ class BuildTask(object):
                 build = HgRevision(build, branch).hash
             flag_str = flags.build_string()
             task_paths = tuple(path + flag_str for path in cls._revision_paths(build.lower(), branch, target_platform))
-            task_template_paths = itertools.product(cls.TASKCLUSTER_APIS, task_paths)
+            task_template_paths = itertools.product((cls.TASKCLUSTER_API,), task_paths)
 
         elif build == 'latest':
             if branch in {'autoland', 'try'}:
@@ -259,16 +261,13 @@ class BuildTask(object):
                 namespace = 'gecko.v2.mozilla-' + branch + '.latest'
             product = 'mobile' if 'android' in target_platform else 'firefox'
             task_path = '/task/%s.%s.%s%s' % (namespace, product, target_platform, flags.build_string())
-            task_template_paths = ((cls.TASKCLUSTER_APIS[0], task_path),)
+            task_template_paths = ((cls.TASKCLUSTER_API, task_path),)
 
         else:
             # try to use build argument directly as a namespace
             task_path = '/task/' + build
             is_namespace = True
-            if '.latest' in build:
-                task_template_paths = ((cls.TASKCLUSTER_APIS[0], task_path),)
-            else:
-                task_template_paths = itertools.product(cls.TASKCLUSTER_APIS, (task_path,))
+            task_template_paths = ((cls.TASKCLUSTER_API, task_path),)
 
         for (template_path, try_wo_opt) in itertools.product(task_template_paths, (False, True)):
 
@@ -305,27 +304,19 @@ class BuildTask(object):
         if branch not in {'autoland', 'try'}:
             branch = 'mozilla-' + branch
         path = '/namespaces/gecko.v2.' + branch + '.pushdate.' + pushdate
-        date_found = False
-        last_exc = None
 
-        for template in cls.TASKCLUSTER_APIS:
-            index_base = template % ('index',)
-            url = index_base + path
-            try:
-                base = HTTP_SESSION.post(url, json={})
-                base.raise_for_status()
-            except requests.exceptions.RequestException as exc:
-                last_exc = exc
-                continue
+        index_base = cls.TASKCLUSTER_API % ('index',)
+        url = index_base + path
+        try:
+            base = HTTP_SESSION.post(url, json={})
+            base.raise_for_status()
+        except requests.exceptions.RequestException as exc:
+            raise FetcherException(exc)
 
-            date_found = True
-            product = 'mobile' if 'android' in target_platform else 'firefox'
-            json = base.json()
-            for namespace in sorted(json['namespaces'], key=lambda x: x['name']):
-                yield (template, '/task/' + namespace['namespace'] + '.' + product + '.' + target_platform)
-
-        if not date_found:
-            raise FetcherException(last_exc)
+        product = 'mobile' if 'android' in target_platform else 'firefox'
+        json = base.json()
+        for namespace in sorted(json['namespaces'], key=lambda x: x['name']):
+            yield cls.TASKCLUSTER_API, '/task/' + namespace['namespace'] + '.' + product + '.' + target_platform
 
     @classmethod
     def _revision_paths(cls, rev, branch, target_platform):
@@ -501,6 +492,7 @@ class Fetcher(object):
         self._branch = branch
         self._flags = BuildFlags(*flags)
         self._platform = platform or Platform()
+        self._task = None
 
         if not isinstance(build, BuildTask):
             # If build doesn't match the following, assume it's a namespace
@@ -566,41 +558,62 @@ class Fetcher(object):
                 if not nearest:
                     raise
 
-                start = None
+                requested = None
                 asc = nearest == Fetcher.BUILD_ORDER_ASC
                 if 'latest' in build:
-                    start = now + timedelta(days=1) if asc else now - timedelta(days=1)
+                    requested = now
                 elif BuildTask.RE_DATE.match(build) is not None:
                     date = datetime.strptime(build, '%Y-%m-%d')
-                    localized = timezone('UTC').localize(date)
-                    start = localized + timedelta(days=1) if asc else localized - timedelta(days=1)
+                    requested = timezone('UTC').localize(date)
                 elif BuildTask.RE_REV.match(build) is not None:
-                    start = HgRevision(build, branch).pushdate
+                    requested = HgRevision(build, branch).pushdate
                 else:
                     # If no match, assume it's a TaskCluster namespace
                     if re.match(r'.*[0-9]{4}\.[0-9]{2}\.[0-9]{2}.*', build) is not None:
                         match = re.search(r'[0-9]{4}\.[0-9]{2}\.[0-9]{2}', build)
                         date = datetime.strptime(match.group(0), '%Y.%m.%d')
-                        start = timezone('UTC').localize(date)
+                        requested = timezone('UTC').localize(date)
                     elif re.match(r'.*revision.*[0-9[a-f]{40}', build):
                         match = re.search(r'[0-9[a-f]{40}', build)
-                        start = HgRevision(match.group(0), branch).pushdate
+                        requested = HgRevision(match.group(0), branch).pushdate
 
                 # If start date is outside the range of the newest/oldest available build, adjust it
                 if asc:
-                    start = min(max(start, now - timedelta(days=364)), now)
+                    start = min(max(requested, now - timedelta(days=364)), now)
                     end = now
                 else:
                     end = now - timedelta(days=364)
-                    start = max(min(start, now), end)
+                    start = max(min(requested, now), end)
+                LOG.debug("searching for nearest build to %s from %s -> %s", requested, start, end)
 
                 while start <= end if asc else start >= end:
-                    try:
-                        self._task = BuildTask(start.strftime('%Y-%m-%d'), branch, self._flags, self._platform)
+                    search_build = start.strftime('%Y-%m-%d')
+
+                    # in the case where a calendar date was specified, we've already tried it directly
+                    if search_build != build:
+                        LOG.debug("trying %s", search_build)
+                        try:
+                            # iterate over all builds for the day, and take the next older/newer build available
+                            build_tasks = BuildTask.iterall(search_build, branch, self._flags, self._platform)
+                            if not asc:
+                                build_tasks = reversed(list(build_tasks))
+
+                            for task in build_tasks:
+                                task_date = timezone('EST').localize(datetime.fromtimestamp(task.rank))
+                                LOG.debug("got %s", task_date)
+                                if (asc and task_date >= requested) or (not asc and task_date <= requested):
+                                    self._task = task
+                                    break
+                        except FetcherException:
+                            LOG.warning('Unable to find build for %s', start.strftime('%Y-%m-%d'))
+
+                    if self._task is not None:
+                        # a task was found
                         break
-                    except FetcherException:
-                        LOG.warning('Unable to find build for %s', start.strftime('%Y-%m-%d'))
-                        start = start + timedelta(days=1) if asc else start - timedelta(days=1)
+
+                    # Increment start date
+                    start = start + timedelta(days=1) if asc else start - timedelta(days=1)
+
                 else:
                     raise FetcherException('Failed to find build near %s' % build)
 
